@@ -4,6 +4,7 @@ import (
 	"fmt"
 
 	logforward "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1alpha1"
+	"github.com/openshift/cluster-logging-operator/pkg/constants"
 	"k8s.io/apimachinery/pkg/util/sets"
 )
 
@@ -24,8 +25,19 @@ func (engine *ConfigGenerator) generateSource(sources sets.String) (results []st
 	if len(templates) == 0 {
 		return results, fmt.Errorf("Unable to generate source configs for supported source types: %v", sources.List())
 	}
+	data := struct {
+		LoggingNamespace           string
+		CollectorPodNamePrefix     string
+		LogStorePodNamePrefix      string
+		VisualizationPodNamePrefix string
+	}{
+		constants.OpenshiftNS,
+		constants.FluentdName,
+		constants.ElasticsearchName,
+		constants.KibanaName,
+	}
 	for _, template := range templates {
-		result, err := engine.Execute(template, "")
+		result, err := engine.Execute(template, data)
 		if err != nil {
 			return results, fmt.Errorf("Error processing template %s: %v", template, err)
 		}
